﻿////------------------------------------------------------------------------------------------
//
//    MindFusion Office Floorplan Designer 
//     Copyright (c) 2012, MindFusion LLC - Bulgaria
//
////------------------------------------------------------------------------------------------

using MindFusion.Diagramming;
using MindFusion.Drawing;

using MindFusionPen = MindFusion.Drawing.Pen;

using System.Drawing;

using SystemPen = System.Drawing.Pen;


namespace FloorplanDesigner
{
   /// <summary>
   /// This is a base class from which all floorplan office furniture items are derived. So far this 
   /// just consists of desks and tables, which are almost identical - only difference is the 
   /// initial size and orientation.
   /// </summary>
   public abstract class NodeFurnitureBase : NodeItemBase
   {
      #region Constructors
      
      // Copy constructor, needed for copy to/from clipboard
      protected NodeFurnitureBase(NodeFurnitureBase copyFrom)
         : base(copyFrom)
      {}


      // Constructor for when user creates an item on the diagram area
      protected NodeFurnitureBase(PointF startPoint, float defaultWidth, float defaultHeight)
      {
          base.Pen = new MindFusionPen(Color.FromArgb(45, 57, 86), 0.4f);
         base.HandlesStyle = HandlesStyle.SquareHandles;

         // Set initial default size of item unless this is a deserialization call
         if (startPoint != PointF.Empty)
         {
            float halfWidth = defaultWidth / 2f;
            float halfHeight = defaultHeight / 2f;
            base.Bounds = RectangleF.FromLTRB(startPoint.X - halfWidth, startPoint.Y - halfHeight,
                                              startPoint.X + halfWidth, startPoint.Y + halfHeight);
         }
      }

      #endregion Constructors


      #region Public and protected override methods

      /// <summary>
      /// Override for the Draw() method to draw a floorplan furniture item. This just draws a 
      /// simple rectangle.
      /// </summary>
      public override void Draw(IGraphics iGraphics, RenderOptions renderOptions)
      {
         using (SystemPen systemPen = base.Pen.CreateGdiPen())
         {
            iGraphics.DrawRectangle(systemPen, base.Bounds.X, base.Bounds.Y, 
                                               base.Bounds.Width, base.Bounds.Height);
         }
      }

      #endregion Public and protected override methods

   }
}
